import React, { useEffect, useMemo, useState } from 'react';
import { Empty, Spin, notification } from 'antd';
import SecurityLayout from '@/layouts/SecurityLayout';
import { appService } from '@/api';
import { SERVICE_INTERFACE_SUCCESS_CODE } from '@/constants';
import PandaBootPage from './panda';


const system_item_name = '引导页模板'; // 系统配置项名称


const BootPageTemplate = {
  default: PandaBootPage,
};

const BootPage = props => {
  const [info, setInfo] = useState({
    first: true,
    loading: true,
    error: false,
  });
  const [template, setTemplate] = useState('default');
  const RenderComponent = useMemo(() => BootPageTemplate[template] || BootPageTemplate.default, [template]);

  useEffect(() => {
    appService
      .sysConfiguration({
        moduleName: system_item_name,
        ignoreSite: true,
      })
      .then(res => {
        const { code, data } = res;
        if (code != SERVICE_INTERFACE_SUCCESS_CODE) {
          notification.error({ message: '提示', duration: 3, description: '系统引导页配置错误' });
          setInfo({ first: false, loading: false, error: true });
          return;
        }
        // if (data === null) notification.info({ message: '提示', duration: 3, description: '未配置系统引导页' });
        setTemplate(data);
        setInfo({ first: false, loading: false, error: false });
      })
      .catch(err => {
        notification.error({ message: '提示', duration: 3, description: '系统引导页配置错误' });
        setInfo({ first: false, loading: false, error: true });
      });
  }, []);

  return (
    <SecurityLayout>{info.loading ? <Spin /> : info.error ? <Empty /> : <RenderComponent {...props} />}</SecurityLayout>
  );
};

export default BootPage;
